@@ -1,7 +1,7 @@
-// $Id: vderegs.cpp 55774 2008-06-12 14:15:21Z wsnyder $  -*- C++ -*-
+// -*- C++ -*-
 //====================================================================
 //
-// Copyright 2002-2008 by Wilson Snyder <wsnyder@wsnyder.org>.  This
+// Copyright 2002-2009 by Wilson Snyder <wsnyder@wsnyder.org>.  This
 // program is free software; you can redistribute it and/or modify it under
 // the terms of either the GNU Lesser General Public License or the Perl
 // Artistic License.
@@ -278,7 +278,7 @@ static struct option long_options[] = {
 };
 
 static void version() {
-    COUT <<"vderegs: #$Id: vderegs.cpp 55774 2008-06-12 14:15:21Z wsnyder $" <<endl;
+    COUT <<"vderegs: $VERSION = '1.461'" <<endl;
 }
 
 static void usage() {
